﻿// *****************************************************************
// *                                                               *
// *       Copyright (c) Fast Corporation, 2017                    *
// *                                                               *
// *   All Rights Reserved.  Unpublished rights  reserved  under   *
// *   the copyright laws of the Japan.                            *
// *                                                               *
// *   The software contained on this media  is  proprietary  to   *
// *   and  embodies  the  confidential  technology  of  Fast      *
// *   Corporation.  Possession, use,  duplication  or             *
// *   dissemination of the software and media is authorized only  *
// *   pursuant to a valid written license from Fast Corporation.  *
// *                                                               *
// *****************************************************************

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;


// -----------------------------------------------------------------
// FVIL Sample Program
// メインダイアログ
//
// 作成者 : N.Kubo
//
// 履歴 : 2017/9/19 初版
//
// Edge2D Sample Program
// -----------------------------------------------------------------


namespace Edge2D
{
    public partial class FormEdge2D : Form
    {
        //画像メモリ格納領域
        private FVIL.Data.CFviImage m_image = new FVIL.Data.CFviImage();

        //画像メモリ格納領域(処理結果格納用)
        private FVIL.Data.CFviImage m_dst = new FVIL.Data.CFviImage();

        private FVIL.Data.CFviImage image_8bit = new FVIL.Data.CFviImage();

        //ビデオ入力クラス
        private FVIL.Video.CFviVideo m_video = null;


        //2次元エッジクラス
        FVIL.Edge.CFviEdge2DCorrelation m_corr_edge = new FVIL.Edge.CFviEdge2DCorrelation();

        //2次元エッジクラス
        FVIL.Edge.CFviEdge2DSobel m_sobel_edge = new FVIL.Edge.CFviEdge2DSobel();

        //2次元エッジ検出パラメータクラス(相関エッジ法)
        private FVIL.Edge.CFviEdge2DCorrelationParam m_corr_param = new FVIL.Edge.CFviEdge2DCorrelationParam();

        //2次元エッジ検出パラメータクラス(Sobel法)
        private FVIL.Edge.CFviEdge2DSobelParam m_sobel_param = new FVIL.Edge.CFviEdge2DSobelParam();

        //エッジ表示用オーバーレイクラス宣言
        private FVIL.GDI.CFviOverlay m_overlayEdge = new FVIL.GDI.CFviOverlay();

        //処理時間計測クラス
        private FVIL.CFviTimeCounter m_timer = new FVIL.CFviTimeCounter();

        //iniファイル設定フォーム
        Form_BROWSEINI formBroseIni = new Form_BROWSEINI();

        //iniファイル名（フルパス）
        public string m_strIniFilePath;
        //ビデオデバイスのオープン状態
        private bool m_flgVideoOpened;

        //時間測定用
        private double msec = 0;

         public FormEdge2D()
        {
            InitializeComponent();
        }



       private void FormEdge2D_Load(object sender, EventArgs e)
        {
           // FVILの初期化
           // アプリケーションを起動した後、 この関数を呼び出してライブラリを初期化してください。
           //  この時、ライセンスの認証が行われます。試用期間中であっても、この処理は必ず行う必要が有ります。
           // 初期化を行わなかった場合は、プロテクトされたクラスの実行ができません。

           FVIL._SetUp.InitVisionLibrary();
           
           //状態変数の初期化
           m_flgVideoOpened = false;
           
           //計測時間テキストボックス初期化
           TextBoxTime.Text = "0";
           
           //トリガモードコンボボックス初期化
           ComboBoxTrigger.Items.Clear();
           ComboBoxTrigger.Items.Add("ノーマル");
           ComboBoxTrigger.Items.Add("内部トリガ");
           ComboBoxTrigger.Items.Add("外部トリガ");
           ComboBoxTrigger.SelectedIndex = 0;


           //エッジフィルタ選択コンボボックス初期化
           comboBoxSelectFilter.Items.Clear();
           comboBoxSelectFilter.Items.Add("相関エッジ");
           comboBoxSelectFilter.Items.Add("ソーベル");
           comboBoxSelectFilter.SelectedIndex = 0;
           
           // 保持するエッジ勾配強度選択コンボボックス
           comboBoxMagMode.Items.Clear();
           comboBoxMagMode.Items.Add("XY");
           comboBoxMagMode.Items.Add("SQRT");
           comboBoxMagMode.SelectedIndex = 0;

        }


        /// <summary>
        /// フォーム表示開始
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 使用許諾を確認します。
        /// </remarks>
        private void FormEdge2D_Shown(object sender, EventArgs e)
        {
            dialogLicence licence_dialog = new dialogLicence();
            if (licence_dialog.ShowDialog(this) != DialogResult.OK)
            {
                this.Close();
                //使用許諾が得られない場合はサンプルプログラムの動作を終了
                return;
            }

            //iniファイル選択
            fnSetIniFile();

            // 描画imageのセット
            cFviImageView1.Image = m_image;

            //オーバーレイの追加
            cFviImageView1.Display.Overlays.Add(m_overlayEdge);

        }



        /// <summary>
        /// iniファイル選択関数
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// iniファイルの選択をします。
        /// </remarks>
        private void fnSetIniFile()
        {
            //iniファイルの選択
            m_strIniFilePath = "";
            if (formBroseIni.ShowDialog(this) == DialogResult.OK)
            {
                m_strIniFilePath = formBroseIni.strIniFilePath;


                if (m_strIniFilePath.Length > 0)
                {
                    try
                    {
                        //設定ファイルのロードとデバイスオープン
                        m_video = FVIL.Video.Function.CreateInstance(m_strIniFilePath);
                        //画像サイズ調整
                        m_video.ChangeImageSize(m_image);
                        m_flgVideoOpened = true;

                        //ステータス表示の更新
                        //トリガモードの取得
                        ComboBoxTrigger.SelectedIndex = (int)m_video.Trigger;

                        //カメラ露光時間の取得
                        if (m_video.DeviceType != FVIL.Video.DeviceType.RICE001)
                        {
                            NumericUpDownExposure.Value = m_video.ExposureTime;
                        }
                        else
                        {
                            tabControlParam.TabPages.Remove(tabPageBoard);
                        }

                        ButtonGrabOne.Enabled = true;
                    }
                    catch (FVIL.CFviException ex)
                    {
                        //エラー処理
                        MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                    catch (System.Exception ex)
                    {
                        //エラー処理
                        MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }

                }
                else if (formBroseIni.UseFileFlg == true)
                {
                    ButtonGrabOne.Enabled = false;
                }
                else
                {
                    //iniファイルが未選択の場合はサンプルプログラムの動作を終了
                    this.Close();
                    return;
                }
            }

        }



        /// <summary>
        /// Trigger Modeコンボボックス
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// ノーマルモード・内部トリガモード・外部トリガモードの選択。
        /// </remarks>
        private void ComboBoxTrigger_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                if (m_flgVideoOpened == true)
                {
                    m_video.Trigger = (uint)ComboBoxTrigger.SelectedIndex;
                    //弊社キャプチャボードはトリガーモードの設定後にセットアップタイムが必要になります｡
                    //本プログラムのセットアップタイムは必要最大値である350msを設定しています。
                    //キャプチャボードによってこの時間は異なります。
                    System.Threading.Thread.Sleep(350);
                }
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }


        /// <summary>
        /// Video Exposure値
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// カメラ露光時間の設定。
        /// </remarks>
        private void NumericUpDownExposure_ValueChanged(object sender, EventArgs e)
        {
            try
            {
                if (m_flgVideoOpened == true)
                {
                    m_video.ExposureTime = (uint)NumericUpDownExposure.Value;
                }
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        /// <summary>
        /// Grab Oneボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// カメラ取り込み。
        /// </remarks>
        private void ButtonGrabOne_Click(object sender, EventArgs e)
        {
            try
            {
                m_overlayEdge.Figures.Clear();
                formBroseIni.UseFileFlg = false;

                //デバイスタイプ
                FVIL.Video.CFviContinuousGrab contgrab;
                switch (m_video.DeviceType)
                {
                    case FVIL.Video.DeviceType.FHC3313:
                        contgrab = ((FVIL.Video.CFviVideoFHC3313)m_video).ContinuousGrab;
                        ((FVIL.Video.CFviContinuousGrabFHC3313)contgrab).MemoryLock(m_image);
                        //時間測定開始
                        m_timer.Start();
                        //カメラ取り込み
                        contgrab.GrabSync(1);
                        //時間測定終了
                        msec = m_timer.Stop();
                        break;
                    default:
                        //時間測定開始
                        m_timer.Start();
                        //カメラ取り込み
                        m_video.GrabImageSync(m_image);
                        //時間測定終了
                        msec = m_timer.Stop();
                        break;
                }
                //測定時間表示
                TextBoxTime.Text = msec.ToString("0.000");

                //再描画
                cFviImageView1.Refresh();
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        
        /// <summary>
        /// LoadFile ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 入力画像ファイルのロード
        /// </remarks>
        /// 
        private void buttonLoadImageFile_Click(object sender, EventArgs e)
        {
            formBroseIni.UseFileFlg = true;

            //入力画像ファイルのロード
            openFileDialog1.FileName = null;
            openFileDialog1.Filter = "Bitmap ファイル (*.bmp;*.dib)|*.bmp;*.dib";
            openFileDialog1.Filter += "|Png ファイル (*.png)|*.png";
            openFileDialog1.Filter += "|Jpeg ファイル (*.jpg;*.jpeg)|*.jpg;*.jpeg";
            openFileDialog1.Filter += "|Tiff ファイル (*.tif;*.tiff)|*.tif;*.tiff";
            openFileDialog1.DefaultExt = "*.bmp";
            if ((openFileDialog1.FileNames.Length <= 0) && (openFileDialog1.ShowDialog(this) == DialogResult.Cancel))
            {
                return;
            }

            try
            {
                FVIL.File.Function.LoadImageFile(openFileDialog1.FileName, m_image, FVIL.PixelMode.Unpacking);
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            // エッジ点描画のクリア
            m_overlayEdge.Figures.Clear();

            cFviImageView1.Image = m_image;
            //再描画
            cFviImageView1.Refresh();
        }


        /// <summary>
        /// 2次元エッジ検出実行
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 
        /// </remarks>
        private void buttonEdge2D_Click(object sender, EventArgs e)
        {
            try
            {
                m_overlayEdge.Figures.Clear();
                cFviImageView1.Image = m_dst;             

                if (comboBoxSelectFilter.SelectedIndex == 0)
                {
                    //2次元エッジ取得(相関エッジフィルタ)

                    m_corr_edge.SrcImages[0] = m_image;
                    m_corr_edge.DstImages[0] = m_dst;
                    m_corr_edge.Validate();
                    m_corr_edge.SaveMode = FVIL.Edge.SaveMode.All;


                     if (comboBoxMagMode.SelectedIndex == 0)
                         m_corr_edge.MagMode = FVIL.Edge.MagMode.XY;
                    else
                         m_corr_edge.MagMode = FVIL.Edge.MagMode.SQRT;
                    


                    int temp1 = (int)numericUpDownRegionHeight.Value;
                    int temp2 = (int)numericUpDownRegionWidth.Value;
                    if ((temp1 <= temp2) && ((temp1 * temp2) <= 255))
                    {
                        m_corr_param.RegionWidth = (int)numericUpDownRegionWidth.Value;
                        m_corr_param.RegionHeight = (int)numericUpDownRegionHeight.Value;
                    }
                    else
                    {
                        MessageBox.Show("局所領域サイズの条件を満たしていません", "Parameter Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        return;
                    }

                    m_corr_param.SigmoidK = double.Parse(textBoxSigmoidK.Text.ToString());
                    m_corr_param.VarThreshold = double.Parse(textBoxVarThreshold.Text.ToString());
                    m_corr_param.EdgeThreshold = (int)numericUpDownEdgeThreshold.Value;
                    m_corr_param.NmsLength = (int)numericUpDownNmsLength.Value;

                    m_corr_edge.Param = m_corr_param;
                    
                    //画像処理実行
                    m_corr_edge.Execute();


                   if(checkEdgeDisp.Checked)
                       fnEdgeDisp(m_corr_edge.Result);
                   
                 
                }
                else
                {
                                      
                    //2次元エッジ取得(ソーベルフィルタ)

                    m_sobel_edge.SrcImages[0] = m_image;
                    m_sobel_edge.DstImages[0] = m_dst;
                    m_sobel_edge.Validate();


                    if (comboBoxMagMode.SelectedIndex == 0)
                        m_sobel_edge.MagMode = FVIL.Edge.MagMode.XY;
                    else
                        m_sobel_edge.MagMode = FVIL.Edge.MagMode.SQRT;
                    

                    m_sobel_edge.SaveMode = FVIL.Edge.SaveMode.All;   


                     //Edge抽出用パラメータ設定
                    m_sobel_param.EdgeThreshold = (int)numericUpDownEdgeThreshold.Value;
                    m_sobel_param.NmsLength = (int)numericUpDownNmsLength.Value;
                    
                    m_sobel_edge.Param = m_sobel_param;
                    
                    
                    //画像処理実行
                    m_sobel_edge.Execute();

                    if (checkEdgeDisp.Checked)
                        fnEdgeDisp(m_sobel_edge.Result);


                }


                //再描画
                cFviImageView1.Refresh();


            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("エッジ検出エラーが発生しました。ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            
            
            }        


        }

    
        /// <summary>    
        /// エッジ点表示    
        /// </summary>   
        /// <param name="edge_result">FVIL.Edge.CFviEdgeResult</param>    
        ///<remarks>    
        ///検出したエッジ点をオーバーレイに表示 
        /// </remarks>
        private void fnEdgeDisp(FVIL.Edge.CFviEdgeResult edge_result)
        {
            //エッジの表示
            for (int i = 0; i < edge_result.Count; i++)
            {
                FVIL.Edge.CFviEdgeData edge = edge_result[i];
                // エッジ位置に ＋ マークを表示 
                FVIL.GDI.CFviGdiPoint pos = new FVIL.GDI.CFviGdiPoint(edge.Position);
                pos.Size = new System.Drawing.Size(3, 1);
                pos.Style = FVIL.GDI.FigureStyle.Cross;
                pos.Pen.Color = System.Drawing.Color.FromArgb(0, 0, 0xFF);
                m_overlayEdge.Figures.Add(pos);
            }
            cFviImageView1.Image = m_image;             

        }


        /// <summary>
        /// 2次元エッジ検出手法選択コンボボックス
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 相関エッジ・ソーベルの選択。
        /// </remarks>
        private void comboBoxSelectFilter_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (comboBoxSelectFilter.SelectedIndex == 0)
            {
                //相関エッジ用パラメータ表示
                numericUpDownRegionHeight.Visible = true;
                numericUpDownRegionWidth.Visible = true;
                textBoxSigmoidK.Visible = true;
                textBoxVarThreshold.Visible = true;
                labelRegionWidth.Visible = true;
                labelRegionHeight.Visible = true;
                labelSigmoidK.Visible = true;
                labelVarThreshold.Visible = true;
                labelCondition1.Visible = true;
                labelCondition2.Visible = true;
                labelCondition3.Visible = true;
                //相関エッジ用パラメータ初期値設定
                numericUpDownEdgeThreshold.Maximum = 255;
                numericUpDownEdgeThreshold.Value = m_corr_param.EdgeThreshold;
                numericUpDownNmsLength.Value = m_corr_param.NmsLength;
            }
            else
            {
                //相関エッジ用パラメータ非表示
                numericUpDownRegionHeight.Visible = false;
                numericUpDownRegionWidth.Visible = false;
                textBoxSigmoidK.Visible = false;
                textBoxVarThreshold.Visible = false;
                labelRegionWidth.Visible = false;
                labelRegionHeight.Visible = false;
                labelSigmoidK.Visible = false;
                labelVarThreshold.Visible = false;
                labelCondition1.Visible = false;
                labelCondition2.Visible = false;
                labelCondition3.Visible = false;
                //ソーベルエッジ用パラメータ初期値設定
                numericUpDownEdgeThreshold.Maximum = 1023;
                numericUpDownEdgeThreshold.Value = m_sobel_param.EdgeThreshold;
                numericUpDownNmsLength.Value = m_sobel_param.NmsLength;
            }
        }

        /// <summary>
        /// x１ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 等倍で表示します。
        /// </remarks>
        private void ButtonMag1_Click(object sender, EventArgs e)
        {
            //画像の表示倍率の取得または設定を行います。1.0と指定すると等倍で表示します。
            //倍率値は、0.5とした場合は、幅・高さ共に1/2となり、面積が1/4になります。
            //3.0とした場合は、幅・高さ共に3倍となり、面積が9倍になります。

            //表示倍率の設定
            cFviImageView1.Display.Magnification = 1.0;
            //再描画
            cFviImageView1.Refresh();

        }

        /// <summary>
        /// Fitボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します。
        /// </remarks>
        private void ButtonFit_Click(object sender, EventArgs e)
        {
            //画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します
            //表示倍率を調整
            cFviImageView1.FitImageSize();
            //再描画
            cFviImageView1.Refresh();

        }

        /// <summary>
        /// ＋ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 現在の倍率に0.5加えた倍率で表示します。
        /// </remarks>
        private void ButtonPlus_Click(object sender, EventArgs e)
        {
            double Value = 0;
            //現倍率の取得
            Value = cFviImageView1.Display.Magnification;
            //表示倍率の設定
            Value = Value + 0.5;
            cFviImageView1.Display.Magnification = Value;
            //再描画
            cFviImageView1.Refresh();

        }

        /// <summary>
        /// －ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 現在の倍率から0.5引いた倍率で表示します。ただし、倍率が０以下になる場合は倍率0.1で表示します。
        /// </remarks>
        private void ButtonMinus_Click(object sender, EventArgs e)
        {
            double Value = 0;

            //現倍率の取得
            Value = cFviImageView1.Display.Magnification;
            Value = Value - 0.5;
            
            if (Value <= 0)
            {
                //０以下を設定するとエラーになるので0.1を設定する
                Value = 0.1;
            }
            
            //表示倍率の設定
            cFviImageView1.Display.Magnification = Value;
            //再描画
            cFviImageView1.Refresh();
        }


        /// <summary>
        /// Save Imageボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 表示画像保存。
        /// </remarks>
        private void ButtonSaveImage_Click(object sender, EventArgs e)
        {
            SaveFileDialog ofdlg = new SaveFileDialog();

            ofdlg.Filter = "画像ファイル(*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat)|*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat";
            ofdlg.Filter += "|Bitmap ファイル (*.bmp;*.dib)|*.bmp;*.dib";
            ofdlg.Filter += "|Png ファイル (*.png)|*.png";
            ofdlg.Filter += "|Jpeg ファイル (*.jpg;*.jpeg)|*.jpg;*.jpeg";
            ofdlg.Filter += "|Tiff ファイル (*.tif;*.tiff)|*.tif;*.tiff";
            ofdlg.Filter += "|Raw ファイル (*.raw)|*.raw";
            ofdlg.Filter += "|すべてのファイル (*.*)|*.*";
            ofdlg.OverwritePrompt = true;

            if (ofdlg.ShowDialog(this) == DialogResult.OK)
            {
                try
                {
                    //この関数は、簡易的に画像ファイルの保存を行う為のものです。 
                    //この関数で指定できないパラメータを指定する必要があれば、 各画像ファイルアクセスクラスを直接使用してください。 
                    FVIL.File.Function.SaveImageFile(ofdlg.FileName, cFviImageView1.Image);

                }
                catch (FVIL.CFviException ex)
                {
                    System.String msg = System.String.Format("ライブラリが例外を発行しました。code={0} func={1}", ex.ErrorCode, ex.Function);
                    switch ((ex.ErrorCode))
                    {
                        case FVIL.ErrorCode.NOT_SUPPORTED:
                        case FVIL.ErrorCode.INVALID_OBJECT:
                            msg += "\r\n" + "サポートされていない画像オブジェクトです。";
                            msg += "\r\n" + "Raw 形式で保存してください。";
                            break;
                    }
                    //エラー処理
                    MessageBox.Show(msg, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
                catch (Exception ex)
                {
                    //エラー処理
                    MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }


        
        /// <summary>
        /// Ascopeチェックボックス
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// ASCOPEの表示を切替えます。
        /// </remarks>
        private void CheckBoxAscope_CheckedChanged(object sender, EventArgs e)
        {
            //ASCOPEオーバレイの設定
            if (CheckBoxAscope.Checked)
            {
                //ASCOPEの表示を有効にする。
                cFviImageView1.Display.OverlayAscope.Active = true;
            }
            else
            {
                //ASCOPEの表示を無効にする。
                cFviImageView1.Display.OverlayAscope.Active = false;
            }

            //再描画
            cFviImageView1.Refresh();

        }
        

    }
}